==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/dashboard.py <==
# -*- coding: utf-8 -*-

import datetime
from django.utils.translation import ugettext_lazy as _
from admin_tools.dashboard import modules
from jmb.fax.models import Fax

class FaxDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Faxes",
            'display': "tabs",
            'children': [
                FaxModels(),
                FaxOtherModels(),
                FaxSettings(),
                FaxPermissions(),
            ]
        }
        super(FaxDashboard, self).__init__(**kwargs)

class FaxModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Models"),
            'models': ('fax.models.Fax',),
        }
        super(FaxModels, self).__init__(**kwargs)

class FaxOtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Others"),
            'models': ('fax.models.Device', 'fax.models.FaxNumber', 'fax.models.Cover'),
        }
        super(FaxOtherModels, self).__init__(**kwargs)

class FaxSettings(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Settings"),
            'models':['fax.models.Settings',],
            }
        super(FaxSettings, self).__init__(**kwargs)

class FaxPermissions(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Permissions"),
            'models':['fax.models.FaxPermission',],
        }
        super(FaxPermissions, self).__init__(**kwargs)

class Faxes(modules.DashboardModule):
    def __init__(self, title, template='admin_tools/dashboard/faxes.html',
                 order_by=None, limit=10, qs=Fax.objects.all(), extra_filters={},
                 children=None, **kwargs
    ):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(Faxes, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs

class ListFaxes(modules.Group):
    """
    fax aggregate dashboard:
    - new fax today
    - fax to read
    """
    def __init__(self, **kwargs):
        today = datetime.date.today()
        kwargs =  {
            'title': _("List Faxes"),
            'children': [
                Faxes(
                    title='Today Fax',
                    order_by='-date_create',
                    limit=None,
                    extra_filters={'date_create__gte': today},
                ),
                Faxes(
                    title='Fax to read',
                    order_by='-date_create',
                    extra_filters={'read': False},
                ),
            ]
        }
        super(ListFaxes, self).__init__(**kwargs)

class FaxModelList(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Fax"),
            'models':['fax.models.Fax',],
        }
        super(FaxModelList, self).__init__(**kwargs)

==> jmb.fax-0.3.tar.gz: jmb.fax-0.3/jmb/fax/dashboard.py <==
# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.fax.models import Fax
from jmb.core.admin import dashboard as jmb_dashboard

class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': "Faxes",
            'display': "tabs",
            'children': [
                Faxes(
                    title='Today Fax',
                    order_by='-date_create',
                    limit=None,
                    extra_filters={'date_create__gte': today},
                ),
                Faxes(
                    title='Fax to read',
                    order_by='-date_create',
                    extra_filters={'read': False},
                ),
                Pages(
                    title=_('Pages'),
                ),
                FaxModels(),
                FaxOtherModels(),
#                FaxSettings(),
                FaxPermissions(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)

class FaxDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': "Faxes",
            'display': "tabs",
            'children': [
                FaxModels(),
                FaxOtherModels(),
#                FaxSettings(),
                FaxPermissions(),
            ]
        }
        super(FaxDashboard, self).__init__(**kwargs)

class FaxModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Models"),
            'models': ('jmb.fax.models.Fax',),
        }
        super(FaxModels, self).__init__(**kwargs)

class FaxOtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Others"),
            'models': ('jmb.fax.models.Device', 'jmb.fax.models.FaxNumber', 'jmb.fax.models.Cover'),
        }
        super(FaxOtherModels, self).__init__(**kwargs)

class FaxSettings(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Settings"),
            'models':['jmb.fax.models.Settings',],
            }
        super(FaxSettings, self).__init__(**kwargs)

class FaxPermissions(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Permissions"),
            'models':['jmb.fax.models.FaxPermission',],
        }
        super(FaxPermissions, self).__init__(**kwargs)

class Faxes(modules.DashboardModule):
    def __init__(self, title, template='admin_tools/fax/faxes.html',
                 order_by=None, limit=10, qs=Fax.objects.all(), extra_filters={},
                 children=None, **kwargs):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(Faxes, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs

class Pages(modules.DashboardModule):
    def __init__(self, title, template='admin_tools/fax/pages.html',
                 order_by=None, limit=10, qs=Fax.objects.all(), extra_filters={},
                 children=None, **kwargs
    ):
        start_day = (datetime.date.today()-datetime.timedelta(days=365)).replace(day=1)
        self.order_by = order_by
        self.template = template
        month = connections[Fax.objects.db].ops.date_trunc_sql('month', 'date_create')
        qs = qs.filter(date_create__gte=start_day)
        self.qs = qs.extra(select={'month': month}).values('month').annotate(
                                     dcount=Sum('pages')).order_by('month')

        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(Pages, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs

class ListFaxes(modules.Group):
    """
    fax aggregate dashboard:
    - new fax today
    - fax to read
    """
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': _("List Faxes"),
            'children': [
                Faxes(
                    title='Today Fax',
                    order_by='-date_create',
                    limit=None,
                    extra_filters={'date_create__gte': today},
                ),
                Faxes(
                    title='Fax to read',
                    order_by='-date_create',
                    extra_filters={'read': False},
                ),
            ]
        }
        super(ListFaxes, self).__init__(**kwargs)

class FaxModelList(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Fax"),
            'models':['jmb.fax.models.Fax',],
        }
        super(FaxModelList, self).__init__(**kwargs)

class DefaultAppDashboard(AppIndexDashboard):
#    class Media:
#        css = ('office_thunder/css/dashboard.css',)
#
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 2

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.fax')
#jmb_dashboard.register_group(DefaultDashboard, 'jmb.fax')
jmb_dashboard.register_group(FaxDashboard, 'jmb.fax')
